# /bin/sh
mkdir ./bin/translations
lrelease ifpgui.pro
cp ./translations/*.qm ./bin/translations
qmake ifpgui.pro
make
echo " "
echo " "
#echo "Making usb iRiver device available to all users."
#echo "You will need root privilage for this."
#su -c ./nonroot.sh
echo "if you have trouble connecting to your iRiver device,"
echo "run the script ./bin/nonroot.sh."
echo " "
echo " "
echo "to run ifpgui: change directory to 'bin' and type './ifpgui'"

